#
# spec file for package python-canonicaljson
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         github_user matrix-org
%define         short_name canonicaljson
Name:           python-%{short_name}%{psuffix}
Version:        1.1.4
Release:        bp155.2.9
Summary:        Canonical JSON for Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/matrix-org/python-canonicaljson
Source:         https://github.com/matrix-org/python-canonicaljson/archive/v%{version}.tar.gz
BuildRequires:  %{python_module frozendict >= 1.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module simplejson}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-frozendict >= 1.0
Requires:       python-simplejson
Requires:       python-six
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module %{short_name}}
%endif
%python_subpackages

%description
This is a Python module which encodes objects and arrays into JSON as per
RFC 7159.

* Sorts object keys so that it yields the same result each time.
* Has no insignificant whitespace to make the output as small as possible.
* Escapes only the characters that must be escaped, U+0000 to U+0019 /
  U+0022 / U+0056, to keep the output as small as possible.
* Uses the shortest escape sequence for each escaped character.
* Encodes the JSON as UTF-8.
* Can encode frozendict immutable dictionaries.

%prep
%setup -q -n python-canonicaljson-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%python_exec -m unittest discover
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*
%endif

%changelog
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.4:
  * Fix error when encoding non-BMP characters on UCS-2 python builds (fixes issue #12).
- Use same syntax for test multibuild like in other pkgs
* Mon Apr 23 2018 jengelh@inai.de
- Update descriptions.
* Sun Apr 22 2018 okurz@suse.com
- Add missing runtime requirement 'python-six'
* Sun Apr 22 2018 okurz@suse.com
- Add package self-test based on multibuild
* Fri Apr 20 2018 okurz@suse.com
- Cleanup duplicate files in singlespec package with fdupes
* Fri Apr 20 2018 okurz@suse.com
- Update to 1.1.3
* Mon Feb 27 2017 okurz@suse.com
- Initial submission
